@@ -7,12 +7,12 @@ class AtomicClassMeta(type):
     def __new__(mcs, name, bases, namespace):
         for k, v in namespace.items():
             if callable(v):
-                namespace[k] = atomic(v)
+                namespace[k] = atomic(v)  # type:ignore
         for base in bases:
             for k, v in base.__dict__.items():
                 if callable(v):
                     if k not in namespace:
-                        namespace[k] = atomic(v)
+                        namespace[k] = atomic(v)  # type:ignore
                     # else:
                     #     breakpoint()
                     #     pass
