@@ -5,3 +5,5 @@ from .os_ import *
 from .callstack import *
 from .get_traceback import *
 from .signals import *
+from .interpreter import *
+from .is_debugging import *
