@@ -1,4 +1,4 @@
-from typing import Union
+from typing import Union, Any, Callable, Dict
 
 from fractions import Fraction
 from ..conditional_variable import ConditionalVariable
@@ -7,6 +7,13 @@ from ..expressions import ProbabilityExpression
 from ..operator import Operator
 from ..protocols import ExpectedValueCalculable
 
+_mapping: Callable[[Any], Dict[Operator, Callable]] = lambda const: {
+    Operator.POW: lambda n: n ** const,
+    Operator.MUL: lambda n: n * const,
+    Operator.DIV: lambda n: n / const,
+    Operator.MODULUS: lambda n: n & const,
+}
+
 
 def expected_value(obj: Union[ConditionalVariable, ProbabilityExpression]) -> Fraction:
     if isinstance(obj, ExpectedValueCalculable):
@@ -15,23 +22,18 @@ def expected_value(obj: Union[ConditionalVariable, ProbabilityExpression]) -> Fr
     if isinstance(obj, ConditionalVariable):
         X = obj
         for n in X.supp:
-            res += n * P(X == n)
+            res += n * P(X == n)  # type:ignore
         return res
     if isinstance(obj.rhs, int):
         const = obj.rhs
         op = obj.op
         X = obj.lhs
 
-        def f(n):
-            return {
-                Operator.POW: lambda n: n ** const,
-                Operator.MUL: lambda n: n * const,
-                Operator.DIV: lambda n: n / const,
-                Operator.MODULUS: lambda n: n & const,
-            }[op](n)
+        def f(n: Union[int, float, Fraction]) -> Union[int, float, Fraction]:
+            return _mapping(const)[op](n)
 
         for n in X.supp:
-            res += f(n) * P(X == n)
+            res += f(n) * P(X == n)  # type:ignore
         return res
     assert False
 
